@@ -1,18 +1,13 @@
 import logging
 import math
-from dataclasses import dataclass
 from datetime import datetime, timedelta, timezone
-from typing import Dict, List, Tuple
+from typing import Collection, Dict, List, Tuple
 
-from metaphor.models.metadata_change_event import (
-    DataPlatform,
-    Dataset,
-    MetadataChangeEvent,
-)
-from serde import deserialize
-from serde.json import from_json
+from metaphor.models.metadata_change_event import DataPlatform, Dataset
+from pydantic import parse_raw_as
+from pydantic.dataclasses import dataclass
 
-from metaphor.common.event_util import EventUtil
+from metaphor.common.event_util import ENTITY_TYPES
 from metaphor.common.extractor import BaseExtractor
 from metaphor.common.filter import DatabaseFilter
 from metaphor.common.logger import get_logger
@@ -27,14 +22,12 @@ logger = get_logger(__name__)
 logging.getLogger("Parser").setLevel(logging.CRITICAL)
 
 
-@deserialize
 @dataclass
 class AccessedObjectColumn:
     columnId: int
     columnName: str
 
 
-@deserialize
 @dataclass
 class AccessedObject:
     objectDomain: str
@@ -62,7 +55,7 @@ class SnowflakeUsageExtractor(BaseExtractor):
 
     async def extract(
         self, config: SnowflakeUsageRunConfig
-    ) -> List[MetadataChangeEvent]:
+    ) -> Collection[ENTITY_TYPES]:
         assert isinstance(config, SnowflakeUsageExtractor.config_class())
 
         logger.info("Fetching usage info from Snowflake")
@@ -139,16 +132,16 @@ class SnowflakeUsageExtractor(BaseExtractor):
         # calculate statistics based on the counts
         UsageUtil.calculate_statistics(self._datasets.values())
 
-        return [EventUtil.build_dataset_event(d) for d in self._datasets.values()]
+        return self._datasets.values()
 
     def _parse_access_logs(self, batch_number: str, access_logs: List[Tuple]) -> None:
         logger.info(f"access logs batch #{batch_number}")
-        for query_id, start_time, accessed_objects in access_logs:
+        for _, start_time, accessed_objects in access_logs:
             self._parse_access_log(start_time, accessed_objects)
 
     def _parse_access_log(self, start_time: datetime, accessed_objects: str) -> None:
         try:
-            objects = from_json(List[AccessedObject], accessed_objects)
+            objects = parse_raw_as(List[AccessedObject], accessed_objects)
             for obj in objects:
                 table_name = obj.objectName.lower()
                 parts = table_name.split(".")
